==> nextcloud-20.0.12.tgz: nextcloud/apps/workflowengine/l10n/hu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "A megadott operátor érvénytelen",
    "The given regular expression is invalid" : "A megadott reguláris kifejezés érvénytelen",
    "The given file size is invalid" : "A megadott fájlméret érvénytelen",
    "The given tag id is invalid" : "A megadott címe azonosító érvénytelen",
    "The given IP range is invalid" : "A megadott IP tartomány érvénytelen",
    "The given IP range is not valid for IPv4" : "A megadott IPv4 tartomány nem érvényes",
    "The given IP range is not valid for IPv6" : "A megadott IPv6 tartomány nem érvényes",
    "The given time span is invalid" : "A megadott időtartam nem érvényes",
    "The given start time is invalid" : "A megadott kezdő idő nem érvényes",
    "The given end time is invalid" : "A megadott vég idő nem érvényes",
    "The given group does not exist" : "A megadott csoport nem létezik",
    "File" : "Fájl",
    "File created" : "Fájl létrehozva",
    "File updated" : "A fájl frissítve",
    "File renamed" : "A fájl átnevezve",
    "File deleted" : "A fájl törölve",
    "File accessed" : "Hozzáférés a fájlhoz",
    "File copied" : "A fájl másolva",
    "Tag assigned" : "Címke hozzárendelve",
    "Someone" : "Valaki",
    "%s created %s" : "%s létrehozta a következőt: %s",
    "%s modified %s" : "%s módosított a következőt: %s",
    "%s deleted %s" : "%s módosította a következőt: %s",
    "%s accessed %s" : "%s hozzáfért a következőhöz: %s",
    "%s renamed %s" : "%s átnevezte a következőt: %s",
    "%s copied %s" : "%s átmásolta a következőt: %s",
    "%s assigned %s to %s" : "%s hozzárendelte a következőt: %s hozzá: %s",
    "Operation #%s does not exist" : "#%s művelet nem létezik",
    "Entity %s does not exist" : "%s entitás nem létezik",
    "Entity %s is invalid" : "%s entitás érvénytelen",
    "No events are chosen." : "Nincs kiválasztva esemény.",
    "Entity %s has no event %s" : "%s entitásnak nincs eseménye %s",
    "Operation %s does not exist" : "%s művelet nem létezik",
    "Operation %s is invalid" : "#%s művelet érvénytelen",
    "At least one check needs to be provided" : "Legalább egy ellenőrzést meg kell adni",
    "The provided operation data is too long" : "A megadott műveleti adatok túl hosszúak",
    "Invalid check provided" : "Érvénytelen ellenőrzést adott meg",
    "Check %s does not exist" : "%s nem létezik, ellenőrizd",
    "Check %s is invalid" : "%s érvénytelen, ellenőrizd",
    "Check %s is not allowed with this entity" : "%s ellenőrzés nem engedélyezett ezzel az entitással",
    "The provided check value is too long" : "A megadott ellenőrzési érték túl hosszú",
    "Check #%s does not exist" : "#%s nem létezik, ellenőrizd",
    "Check %s is invalid or does not exist" : "%s érvénytelen vagy nem létezik, ellenőrizd",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud munkafolyamat motor",
    "Select a filter" : "Válasszon egy szűrőt",
    "Select a comparator" : "Válasszon összehasonlítót",
    "Select a file type" : "Válasszon egy fájltípust",
    "e.g. httpd/unix-directory" : "például. httpd/unix-directory",
    "Folder" : "Mappa",
    "Images" : "Képek",
    "Office documents" : "Office dokumentumok",
    "PDF documents" : "PDF dokumentumok",
    "Custom mimetype" : "Egyéni mime típus",
    "Select a tag" : "Válasszon ki egy címkét",
    "No results" : "Nincs találat",
    "%s (invisible)" : "%s (láthatatlan)",
    "%s (restricted)" : "%s (korlátozott)",
    "Please enter a valid time span" : "Kérjük, adjon meg érvényes időtartamot",
    "Select a request URL" : "Válassza ki a kérelem URL-jét",
    "Predefined URLs" : "Elődefiniált URL-ek",
    "Files WebDAV" : "WebDAV fálok",
    "Others" : "Egyebek",
    "Custom URL" : "Egyéni URL",
    "Select a user agent" : "Válasszon felhasználói ügynököt",
    "Android client" : "Android kliens",
    "iOS client" : "iOS klens",
    "Desktop client" : "Asztali kliens",
    "Thunderbird & Outlook addons" : "Thunderbird és Outlook bővítmények",
    "Custom user agent" : "Egyéni felhasználói ügynök",
    "At least one event must be selected" : "Legalább egy eseményt ki kell választani",
    "Add new flow" : "Új folyamat hozzáadása",
    "When" : "Mikor",
    "and" : "és",
    "Cancel" : "Mégse",
    "Delete" : "Törlés",
    "The configuration is invalid" : "A konfiguráció érvénytelen",
    "Active" : "Aktív",
    "Save" : "Mentés",
    "Available flows" : "Rendelkezésre álló munkafolyamatok",
    "For details on how to write your own flow, check out the development documentation." : "A saját folyamatának megírásának részleteiért, lásd a fejlesztési dokumentációt.",
    "More flows" : "Több munkafolyamat",
    "Show less" : "Kevesebbet megjelenítése",
    "Show more" : "Több megjelenítése",
    "Configured flows" : "Beállított folyamatok",
    "Your flows" : "Az Ön folyamatai",
    "matches" : "egyezik",
    "does not match" : "nem egyezik",
    "is" : "ez",
    "is not" : "nem ez",
    "File name" : "Fájlnév",
    "File MIME type" : "Fájl MIME típus",
    "File size (upload)" : "Fájl méret (feltöltés)",
    "less" : "kisebb",
    "less or equals" : "kisebb vagy egyenlő",
    "greater or equals" : "nagyobb vagy egyenlő",
    "greater" : "nagyobb",
    "Request remote address" : "Távoli cím kérés",
    "matches IPv4" : "IPv4 egyezik",
    "does not match IPv4" : "IPv4 nem egyezik",
    "matches IPv6" : "IPv6 egyezik",
    "does not match IPv6" : "IPv6 nem egyezik",
    "File system tag" : "Fájlrendszer címke",
    "is tagged with" : "címkézve ezzel",
    "is not tagged with" : "nem címkézve ezzel",
    "Request URL" : "URL kérés",
    "Request time" : "Idő kérés",
    "between" : "közötte",
    "not between" : "nincs közötte",
    "Request user agent" : "Böngésző kérés",
    "User group membership" : "Felhasználói csoport tagság",
    "is member of" : "tagja ennek",
    "is not member of" : "nem tagja ennek",
    "Browse the app store" : "Alkalmazás bolt böngészése"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/workflowengine/l10n/hu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "A megadott operátor érvénytelen",
    "The given regular expression is invalid" : "A megadott reguláris kifejezés érvénytelen",
    "The given file size is invalid" : "A megadott fájlméret érvénytelen",
    "The given tag id is invalid" : "A megadott címe azonosító érvénytelen",
    "The given IP range is invalid" : "A megadott IP tartomány érvénytelen",
    "The given IP range is not valid for IPv4" : "A megadott IPv4 tartomány nem érvényes",
    "The given IP range is not valid for IPv6" : "A megadott IPv6 tartomány nem érvényes",
    "The given time span is invalid" : "A megadott időtartam nem érvényes",
    "The given start time is invalid" : "A megadott kezdő idő nem érvényes",
    "The given end time is invalid" : "A megadott vég idő nem érvényes",
    "The given group does not exist" : "A megadott csoport nem létezik",
    "File" : "Fájl",
    "File created" : "Fájl létrehozva",
    "File updated" : "A fájl frissítve",
    "File renamed" : "A fájl átnevezve",
    "File deleted" : "A fájl törölve",
    "File accessed" : "Hozzáférés a fájlhoz",
    "File copied" : "A fájl másolva",
    "Tag assigned" : "Címke hozzárendelve",
    "Someone" : "Valaki",
    "%s created %s" : "%s létrehozta a következőt: %s",
    "%s modified %s" : "%s módosított a következőt: %s",
    "%s deleted %s" : "%s módosította a következőt: %s",
    "%s accessed %s" : "%s hozzáfért a következőhöz: %s",
    "%s renamed %s" : "%s átnevezte a következőt: %s",
    "%s copied %s" : "%s átmásolta a következőt: %s",
    "%s assigned %s to %s" : "%s hozzárendelte a következőt: %s hozzá: %s",
    "Operation #%s does not exist" : "#%s művelet nem létezik",
    "Entity %s does not exist" : "%s entitás nem létezik",
    "Entity %s is invalid" : "%s entitás érvénytelen",
    "No events are chosen." : "Nincs kiválasztva esemény.",
    "Entity %s has no event %s" : "%s entitásnak nincs eseménye %s",
    "Operation %s does not exist" : "%s művelet nem létezik",
    "Operation %s is invalid" : "#%s művelet érvénytelen",
    "At least one check needs to be provided" : "Legalább egy ellenőrzést meg kell adni",
    "The provided operation data is too long" : "A megadott műveleti adatok túl hosszúak",
    "Invalid check provided" : "Érvénytelen ellenőrzést adott meg",
    "Check %s does not exist" : "%s nem létezik, ellenőrizd",
    "Check %s is invalid" : "%s érvénytelen, ellenőrizd",
    "Check %s is not allowed with this entity" : "%s ellenőrzés nem engedélyezett ezzel az entitással",
    "The provided check value is too long" : "A megadott ellenőrzési érték túl hosszú",
    "Check #%s does not exist" : "#%s nem létezik, ellenőrizd",
    "Check %s is invalid or does not exist" : "%s érvénytelen vagy nem létezik, ellenőrizd",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Nextcloud munkafolyamat motor",
    "Select a filter" : "Válasszon egy szűrőt",
    "Select a comparator" : "Válasszon összehasonlítót",
    "Select a file type" : "Válasszon egy fájltípust",
    "e.g. httpd/unix-directory" : "például. httpd/unix-directory",
    "Folder" : "Mappa",
    "Images" : "Képek",
    "Office documents" : "Office dokumentumok",
    "PDF documents" : "PDF dokumentumok",
    "Custom mimetype" : "Egyéni mime típus",
    "Select a tag" : "Válasszon ki egy címkét",
    "No results" : "Nincs találat",
    "%s (invisible)" : "%s (láthatatlan)",
    "%s (restricted)" : "%s (korlátozott)",
    "Please enter a valid time span" : "Kérjük, adjon meg érvényes időtartamot",
    "Select a request URL" : "Válassza ki a kérelem URL-jét",
    "Predefined URLs" : "Elődefiniált URL-ek",
    "Files WebDAV" : "WebDAV fálok",
    "Others" : "Egyebek",
    "Custom URL" : "Egyéni URL",
    "Select a user agent" : "Válasszon felhasználói ügynököt",
    "Android client" : "Android kliens",
    "iOS client" : "iOS klens",
    "Desktop client" : "Asztali kliens",
    "Thunderbird & Outlook addons" : "Thunderbird és Outlook bővítmények",
    "Custom user agent" : "Egyéni felhasználói ügynök",
    "At least one event must be selected" : "Legalább egy eseményt ki kell választani",
    "Add new flow" : "Új folyamat hozzáadása",
    "When" : "Mikor",
    "and" : "és",
    "Cancel" : "Mégse",
    "Delete" : "Törlés",
    "The configuration is invalid" : "A konfiguráció érvénytelen",
    "Active" : "Aktív",
    "Save" : "Mentés",
    "Available flows" : "Rendelkezésre álló munkafolyamatok",
    "For details on how to write your own flow, check out the development documentation." : "A saját folyamatának megírásának részleteiért, lásd a fejlesztési dokumentációt.",
    "More flows" : "Több munkafolyamat",
    "Browse the App Store" : "Alkalmazástár böngészése",
    "Show less" : "Kevesebbet megjelenítése",
    "Show more" : "Több megjelenítése",
    "Configured flows" : "Beállított folyamatok",
    "Your flows" : "Az Ön folyamatai",
    "matches" : "egyezik",
    "does not match" : "nem egyezik",
    "is" : "ez",
    "is not" : "nem ez",
    "File name" : "Fájlnév",
    "File MIME type" : "Fájl MIME típus",
    "File size (upload)" : "Fájl méret (feltöltés)",
    "less" : "kisebb",
    "less or equals" : "kisebb vagy egyenlő",
    "greater or equals" : "nagyobb vagy egyenlő",
    "greater" : "nagyobb",
    "Request remote address" : "Távoli cím kérés",
    "matches IPv4" : "IPv4 egyezik",
    "does not match IPv4" : "IPv4 nem egyezik",
    "matches IPv6" : "IPv6 egyezik",
    "does not match IPv6" : "IPv6 nem egyezik",
    "File system tag" : "Fájlrendszer címke",
    "is tagged with" : "címkézve ezzel",
    "is not tagged with" : "nem címkézve ezzel",
    "Request URL" : "URL kérés",
    "Request time" : "Idő kérés",
    "between" : "közötte",
    "not between" : "nincs közötte",
    "Request user agent" : "Böngésző kérés",
    "User group membership" : "Felhasználói csoport tagság",
    "is member of" : "tagja ennek",
    "is not member of" : "nem tagja ennek",
    "Browse the app store" : "Alkalmazástár böngészése"
},
"nplurals=2; plural=(n != 1);");
